@@ -14,7 +14,6 @@
 Scale <- ggproto("Scale", NULL,
 
   call = NULL,
-
   aesthetics = aes(),
   scale_name = NULL,
   palette = function() {
@@ -107,16 +106,20 @@ Scale <- ggproto("Scale", NULL,
     stop("Not implemented", call. = FALSE)
   },
 
-  #  if scale contains a NULL, use the default scale range
+  #  if scale is a function, apply it to the default (inverted) scale range
+  #  if scale is NULL, use the default scale range
   #  if scale contains a NA, use the default range for that axis, otherwise
   #  use the user defined limit for that axis
   get_limits = function(self) {
     if (self$is_empty()) return(c(0, 1))
 
-    if (!is.null(self$limits)) {
-      ifelse(!is.na(self$limits), self$limits, self$range$range)
-    } else {
+    if (is.null(self$limits)) {
       self$range$range
+    } else if (is.function(self$limits)) {
+      # if limits is a function, it expects to work in data space
+      self$trans$transform(self$limits(self$trans$inverse(self$range$range)))
+    } else {
+      ifelse(is.na(self$limits), self$range$range, self$limits)
     }
   },
 
@@ -526,8 +529,12 @@ ScaleDiscrete <- ggproto("ScaleDiscrete", Scale,
 #'   - A character vector giving labels (must be same length as `breaks`)
 #'   - A function that takes the breaks as input and returns labels
 #'     as output
-#' @param limits A numeric vector of length two providing limits of the scale.
-#'   Use `NA` to refer to the existing minimum or maximum.
+#' @param limits One of:
+#'   - `NULL` to use the default scale range
+#'   - A numeric vector of length two providing limits of the scale.
+#'     Use `NA` to refer to the existing minimum or maximum
+#'   - A function that accepts the existing (automatic) limits and returns
+#'     new limits
 #' @param rescaler  Used by diverging and n colour gradients
 #'   (i.e. [scale_colour_gradient2()], [scale_colour_gradientn()]).
 #'   A function used to scale the input values to the range \[0, 1].
@@ -537,8 +544,9 @@ ScaleDiscrete <- ggproto("ScaleDiscrete", Scale,
 #' @param na.value Missing values will be replaced with this value.
 #' @param trans Either the name of a transformation object, or the
 #'   object itself. Built-in transformations include "asn", "atanh",
-#'   "boxcox", "exp", "identity", "log", "log10", "log1p", "log2",
-#'   "logit", "probability", "probit", "reciprocal", "reverse" and "sqrt".
+#'   "boxcox", "date", "exp", "hms", "identity", "log", "log10", "log1p", "log2",
+#'   "logit", "modulus", "probability", "probit", "pseudo_log", "reciprocal",
+#'   "reverse", "sqrt" and "time".
 #'
 #'   A transformation object bundles together a transform, its inverse,
 #'   and methods for generating breaks and labels. Transformation objects
@@ -568,7 +576,7 @@ continuous_scale <- function(aesthetics, scale_name, palette, name = waiver(),
   }
 
   trans <- as.trans(trans)
-  if (!is.null(limits)) {
+  if (!is.null(limits) && !is.function(limits)) {
     limits <- trans$transform(limits)
   }
 
